@@ -1,15 +1,15 @@
 package Layout::Manager::Compass;
 use Moose;
 
-use MooseX::AttributeHelpers;
-
 extends 'Layout::Manager';
 
 override('do_layout', sub {
-    my ($self, $container, $parent) = @_;
+    my ($self, $container) = @_;
 
     my $bbox = $container->inside_bounding_box;
 
+    my $coheight = $container->outside_height;
+    my $cowidth = $container->outside_width;
     my $cwidth = $bbox->width;
     my $cheight = $bbox->height;
 
@@ -77,7 +77,6 @@ override('do_layout', sub {
         my $sheight = $edges{east}->{height};
         $self->_geassign($sheight, $edges{west}->{height});
         $self->_geassign($sheight, $edges{center}->{height});
-        # 
         $self->_geassign($cheight, $cheight + $sheight);
     }
     $self->_geassign($cwidth, $edges{east}->{width} + $edges{west}->{width}
@@ -213,6 +212,8 @@ override('do_layout', sub {
     $self->_geassign($side_width, $edges{south}->{width});
     $self->_geassign($side_width, $edges{center}->{width} + $edges{east}->{width} + $edges{west}->{width});
 
+    $cheight += $coheight;
+
     # Increase the minimum height and width of the container to accomodate
     # the laid out components.
     $container->minimum_width($side_width);
@@ -272,6 +273,7 @@ edges will take up the full width of the container.
   |  e  |       center       |  a  |
   |  s  |                    |  s  |
   |  t  |                    |  t  |
+  |     |                    |     |
   +-----+--------------------+-----+
   |              south             |
   +--------------------------------+
